@@ -330,7 +330,7 @@ class MSData:
         self.intensityBPC = self.intensityBPC / np.max(self.intensityBPC) * 100
 
 
-    def plotBPC(self, pltName, fontsize=20, dpi=300):
+    def plotBPC(self, pltName, fontsize=20, dpi=300, figsize=(6, 4)):
         """
         Function to plot BPC.
 
@@ -342,9 +342,12 @@ class MSData:
             Font size of the plot.
         dpi: int
             Resolution of the plot.
+        figsize: tuple
+            Size of the plot.
         """
 
-        plt.plot(self.rtBPC, self.intensityBPC, color="black", linewidth=1, dpi=dpi)
+        plt.figure(figsize=figsize, dpi=dpi)
+        plt.plot(self.rtBPC, self.intensityBPC, color="black", linewidth=1)
         plt.xlabel("Retention time, min", fontname='Arial', fontsize=fontsize, labelpad=5)
         plt.ylabel("Intensity, %", fontname='Arial', fontsize=fontsize, labelpad=5)
         plt.xticks(fontname='Arial', fontsize=fontsize)
@@ -844,7 +847,7 @@ def outputConfig(name, timePoints, gradient):
     df.to_csv(fname, index=False)
 
 
-def outputGradientFig(name, gradient, timePoints, fontsize=20, dpi=600):
+def outputGradientFig(name, gradient, timePoints, fontsize=20, dpi=600, figsize=(6, 4)):
     """
     Function to output the gradient figure in png.
 
@@ -860,9 +863,12 @@ def outputGradientFig(name, gradient, timePoints, fontsize=20, dpi=600):
         Font size of the figure.
     dpi: int
         Resolution of the figure.
+    figsize: tuple
+        Size of the figure.
     """
 
-    plt.plot(timePoints, gradient, color="black", linewidth=1, dpi=dpi)
+    plt.figure(figsize=figsize, dpi=dpi)
+    plt.plot(timePoints, gradient, color="black", linewidth=1)
     plt.xlabel("Retention time, min", fontname='Arial', fontsize=fontsize, labelpad=2)
     plt.ylabel("Mobile phase, %", fontname='Arial', fontsize=fontsize, labelpad=2)
     plt.xticks(fontname='Arial', fontsize=fontsize)
